# -*- coding: utf-8 -*-
from setuptools import setup

setup(
    name='pkg_demo',
    version='0.0.1',
    packages=['hello'],
    url='https://www.chenghuichao.com',
    license='LICENSE',
    author='huichao',
    author_email='cheng.huichao@yahoo.com',
    description='test'
)
